translate.tools.poconflicts

Package translate :: Package tools :: Module poconflicts |
[hide private]
[frames] | no frames]

# Module poconflicts

source code

Conflict finder for Gettext PO localization files

See: http://translate.sourceforge.net/wiki/toolkit/poconflicts for examples and usage instructions

Classes | [hide private]
| ConflictOptionParser a specialized Option Parser for the conflict tool...

Functions | [hide private]
main() | source code

Imports: sys, os, factory, po, optrecurse